@@ -16,14 +16,15 @@
     the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
     Boston, MA 02110-1301, USA.
 */
+
 #ifndef KCARDDIALOG_H
 #define KCARDDIALOG_H
 
-#include <QtGui/QWidget>
-#include <kdialog.h>
-#include <kconfig.h>
+#include <QDialog>
+#include <QWidget>
+
+#include <KConfig>
 
-class QListWidgetItem;
 class KCardWidgetPrivate;
 class KCardWidget;
 
@@ -33,15 +34,15 @@ class KCardWidget;
  * @short A convenience class to display a standalone card selection dialog.
  *
  * This is a simple convenience class to embed the @ref KCardWidget into a
- * KDialog that has an OK and Cancel button and an appropriate caption.
+ * QDialog that has an OK and Cancel button and an appropriate caption.
  *
  * Usage Example:
  * \code
- *   KConfigGroup(KGlobal::config(),"CardOptions");
- *   KCardWidget* cardwiget = new KCardwidget();
+ *   KConfigGroup(KSharedConfig::openConfig(),"CardOptions");
+ *   KCardWidget *cardwiget = new KCardwidget();
  *   cardwidget->readSettings(configGroup);
  *   KCardDialog dlg(cardwidget);
- *   if(dlg.exec() == QDialog::Accepted)
+ *   if (dlg.exec() == QDialog::Accepted)
  *   {
  *     cardwidget->saveSettings(configGroup);
  *     configGroup.sync();
@@ -50,11 +51,11 @@ class KCardWidget;
  * \endcode
  *
  */
-class KCardDialog : public KDialog
+class KCardDialog : public QDialog
 {
-  Q_OBJECT
+    Q_OBJECT
 public:
-  explicit KCardDialog(KCardWidget* widget);
+    explicit KCardDialog(KCardWidget *widget);
 };
 
 /**
@@ -68,7 +69,7 @@ public:
  * offered as well as used specified ones.
  *
  * This class can be used in two ways: Embedding it into an existing
- * dialog or creating a small KDialog just for the card deck selection.
+ * dialog or creating a small QDialog just for the card deck selection.
  *
  * Card sets (front and back) are identified by their (translated) names.
  *
@@ -80,45 +81,44 @@ public:
  */
 class KCardWidget : public QWidget
 {
-  Q_OBJECT
+    Q_OBJECT
 
 public:
+    /**
+     * Constructs a card deck selection widget.
+     *
+     * @param parent The parent widget of the widget, if any.
+     */
+    explicit KCardWidget (QWidget *parent = NULL);
 
-   /**
-    * Constructs a card deck selection widget.
-    *
-    * @param parent The parent widget of the widget, if any.
-    */
-   explicit KCardWidget (QWidget* parent = NULL);
+    /**
+     * Read the settings from a config file
+     * @param group the configuration group
+     */
+    void readSettings(const KConfigGroup &group);
 
-   /**
-    * Read the settings from a config file
-    * @param group the configuration group
-    */
-   void readSettings(const KConfigGroup& group);
+    /**
+     * Destructs a card deck selection dialog.
+     */
+    ~KCardWidget();
 
-   /**
-    * Destructs a card deck selection dialog.
-    */
-   ~KCardWidget();
+    /**
+     * Saves the KCardWidget config into a config file.
+     * These settings are used by @ref KCardWidget.
+     */
+    void saveSettings(KConfigGroup &group) const;
 
-   /**
-    * Saves the KCardWidget config into a config file.
-    * These settings are used by @ref KCardWidget.
-    */
-   void saveSettings(KConfigGroup& group) const;
+    /**
+     * set the name of the card set (front side)
+     * @param name the new name to select as front side
+     */
+    void setDeckName(const QString &name);
 
-   /**
-    * set the name of the card set (front side)
-    * @param name the new name to select as front side
-    */
-   void setDeckName(const QString& name);
-
-   /**
-    * Retrieve the name of the card set (front side) from the dialog.
-    * @return The card set name.
-    */
-   QString deckName() const;
+    /**
+     * Retrieve the name of the card set (front side) from the dialog.
+     * @return The card set name.
+     */
+    QString deckName() const;
 
 protected:
     void insertCardIcons();
@@ -135,10 +135,8 @@ protected Q_SLOTS:
     void updateSelection();
 
 private:
-   /**
-    * The dialog data.
-    */
-   KCardWidgetPrivate* const d;
+    /** The dialog data. */
+    KCardWidgetPrivate *const d;
 };
 
 #endif
